@@ -27,19 +27,10 @@
 #include <agentbase.h>
 #include <collection.h>
 
-#include <QTimer>
-#include <QDateTime>
 #include <QList>
 #include "scheduler.h"
 #include "index.h"
 
-class KJob;
-class AbstractIndexer;
-
-namespace Akonadi
-{
-class ItemFetchJob;
-}
 
 class AkonadiIndexingAgent : public Akonadi::AgentBase, public Akonadi::AgentBase::ObserverV3
 {
